(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[      7400,        230]
NotebookOptionsPosition[      6749,        202]
NotebookOutlinePosition[      7088,        217]
CellTagsIndexPosition[      7045,        214]
WindowFrame->Normal
ContainsDynamic->False*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["\<\
Sun Source  (contributed by Ben Jacobson, Illumitech, www.illumitech.com )

\
\>", "Section",
 CellChangeTimes->{{3.418046288453125*^9, 3.4180462895625*^9}, {
  3.4256879116895247`*^9, 3.425687931247888*^9}, {3.425687970481832*^9, 
  3.42568801019195*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Needs", "[", "\"\<Rayica`Rayica`\>\"", "]"}]], "Input",
 CellChangeTimes->{{3.414891670203125*^9, 3.414891684265625*^9}, 
   3.415001134796875*^9}],

Cell[CellGroupData[{

Cell["+++++++++++++++++++++++++", "Print",
 CellChangeTimes->{3.418682425703125*^9, 3.41868250140625*^9}],

Cell[BoxData["\<\"Rayica 3.0 was loaded in 5 s and needs 10196 kilobytes of \
memory on top of 7247 kilobytes already used\"\>"], "Print",
 CellChangeTimes->{3.418682425703125*^9, 3.418682507421875*^9}]
}, Open  ]]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"$HistoryLength", "=", "5"}], ";"}]], "Input",
 CellChangeTimes->{{3.414891687453125*^9, 3.4148916919375*^9}}],

Cell[CellGroupData[{

Cell["\<\
Light sources

( for an improvement,  users might also to set the
grid at the surface of the mirror, and have rays coming in to each point on
the grid with a Monte Carlo angular distribution) \
\>", "Subsection",
 CellChangeTimes->{{3.418121518421875*^9, 3.41812152021875*^9}, {
  3.425688013928389*^9, 3.425688027768062*^9}, {3.4256880870641203`*^9, 
  3.425688123064714*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"LambertianDisk", "[", 
   RowBox[{"diam_", ",", "halfangle_", ",", "nrays_", ",", "opts___"}], "]"}],
   ":=", 
  RowBox[{"Block", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"posntable", ",", "tilttable"}], "}"}], ",", 
    RowBox[{
     RowBox[{"posntable", "=", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"Block", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"r", "=", 
             SqrtBox[
              RowBox[{"RandomReal", "[", 
               RowBox[{"{", 
                RowBox[{"0", ",", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   FractionBox["diam", "2"], ")"}], "2"]}], "}"}], "]"}]]}], 
            ",", 
            RowBox[{"\[Theta]", "=", 
             RowBox[{"RandomReal", "[", 
              RowBox[{"{", 
               RowBox[{"0", ",", 
                RowBox[{"2", " ", "\[Pi]"}]}], "}"}], "]"}]}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", 
            RowBox[{"r", " ", 
             RowBox[{"Cos", "[", "\[Theta]", "]"}]}], ",", 
            RowBox[{"r", " ", 
             RowBox[{"Sin", "[", "\[Theta]", "]"}]}]}], "}"}]}], "]"}], ",", 
        RowBox[{"{", "nrays", "}"}]}], "]"}]}], ";", 
     RowBox[{"tilttable", "=", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"Block", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"\[Phi]", "=", 
             RowBox[{"ArcSin", "[", 
              SqrtBox[
               RowBox[{"RandomReal", "[", 
                RowBox[{"{", 
                 RowBox[{"0", ",", 
                  SuperscriptBox[
                   RowBox[{"Sin", "[", "halfangle", "]"}], "2"]}], "}"}], 
                "]"}]], "]"}]}], ",", 
            RowBox[{"\[Theta]", "=", 
             RowBox[{"RandomReal", "[", 
              RowBox[{"{", 
               RowBox[{"0", ",", 
                RowBox[{"2", " ", "\[Pi]"}]}], "}"}], "]"}]}]}], "}"}], ",", 
          RowBox[{"Flatten", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Cos", "[", "\[Phi]", "]"}], ",", 
             RowBox[{
              RowBox[{"Sin", "[", "\[Phi]", "]"}], " ", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"Cos", "[", "\[Theta]", "]"}], ",", 
                RowBox[{"Sin", "[", "\[Theta]", "]"}]}], "}"}]}]}], "}"}], 
           "]"}]}], "]"}], ",", 
        RowBox[{"{", "nrays", "}"}]}], "]"}]}], ";", 
     RowBox[{"BundleOfRays", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"RayStart", ",", "posntable"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"RayTilt", ",", "tilttable"}], "}"}]}], "}"}], ",", 
       "opts"}], "]"}]}]}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"sunsource", "[", 
   RowBox[{
   "xmirror_", ",", "startclearance_", ",", "centerang_", ",", "halfang_", 
    ",", "nrays_"}], "]"}], ":=", 
  RowBox[{"Move", "[", 
   RowBox[{
    RowBox[{"GridOfRays", "[", 
     RowBox[{
      RowBox[{"Move", "[", 
       RowBox[{
        RowBox[{"LambertianDisk", "[", 
         RowBox[{".0001", ",", "halfang", ",", "nrays"}], "]"}], ",", 
        RowBox[{
         RowBox[{"-", "startclearance"}], 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Cos", "[", 
            RowBox[{"centerang", "/", "2"}], "]"}], ",", "0", ",", 
           RowBox[{"-", 
            RowBox[{"Sin", "[", 
             RowBox[{"centerang", "/", "2"}], "]"}]}]}], "}"}]}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Cos", "[", 
           RowBox[{"centerang", "/", "2"}], "]"}], ",", "0", ",", 
          RowBox[{"-", 
           RowBox[{"Sin", "[", 
            RowBox[{"centerang", "/", "2"}], "]"}]}]}], "}"}]}], "]"}], ",", 
      RowBox[{".95", 
       RowBox[{"{", 
        RowBox[{"4", ",", "6"}], "}"}]}], ",", 
      RowBox[{"NumberOfRays", "\[Rule]", "6"}]}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"xmirror", ",", "0", ",", "0"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Cos", "[", 
       RowBox[{"centerang", "/", "2"}], "]"}], ",", "0", ",", 
      RowBox[{"-", 
       RowBox[{"Sin", "[", 
        RowBox[{"centerang", "/", "2"}], "]"}]}]}], "}"}]}], "]"}]}]], "Input",\

 CellChangeTimes->{{3.4180509490625*^9, 3.4180510903125*^9}, 
   3.418051146890625*^9, 3.41808965515625*^9, {3.41812145946875*^9, 
   3.418121460203125*^9}, {3.41812319275*^9, 3.41812321375*^9}, {
   3.418123997734375*^9, 3.4181240408125*^9}, {3.41812410309375*^9, 
   3.418124129296875*^9}, {3.418124356546875*^9, 3.418124359421875*^9}, 
   3.4181244713125*^9, {3.41868151378125*^9, 3.41868151896875*^9}}]
}, Open  ]]
}, Open  ]]
},
WindowSize->{1267, 675},
WindowMargins->{{-34, Automatic}, {126, Automatic}},
FrontEndVersion->"6.0 for Mac OS X x86 (32-bit) (June 19, 2007)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[590, 23, 266, 7, 111, "Section"],
Cell[CellGroupData[{
Cell[881, 34, 171, 3, 27, "Input"],
Cell[CellGroupData[{
Cell[1077, 41, 105, 1, 20, "Print"],
Cell[1185, 44, 202, 2, 20, "Print"]
}, Open  ]]
}, Open  ]],
Cell[1414, 50, 144, 3, 27, "Input"],
Cell[CellGroupData[{
Cell[1583, 57, 387, 9, 94, "Subsection"],
Cell[1973, 68, 2839, 79, 128, "Input"],
Cell[4815, 149, 1906, 49, 58, "Input"]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)

